#include <iostream>
#include <vector>
#include <set>
#include <unordered_map>
#include <map>
#include <stack>
#include <queue>
#include <cassert>
#include <algorithm>
#include <cmath>

using namespace std;
using ll = long long;
using ld = long double;

const int INT_INF = 1e9 + 10;
const ll LL_INF = 1e18 + 10;
const ld PI = acos(-1);

const int MOD = 1e9 + 7;

int sum(int a, int b) {
	if (a + b >= MOD) {
		return a + b - MOD;
	}
	return a + b;
}

class Segment_tree {
	int n;
	vector<int> tree;
	int build(int u, int l, int r, const vector<int>& a) {
		if (l + 1 == r) {
			tree[u] = a[l];
			return tree[u];
		}
		int m = (l + r) / 2;
		tree[u] = max(build(2 * u + 1, l, m, a), build(2 * u + 2, m, r, a));
	}
	int _get_max(int u, int l, int r, int lq, int rq) {
		if (l >= rq || r <= lq) {
			return -INT_INF;
		}
		if (l >= lq && r <= rq) {
			return tree[u];
		}
		int m = (l + r) / 2;
		return max(_get_max(2 * u + 1, l, m, lq, rq), _get_max(2 * u + 2, m, r, lq, rq));
	}
public: 
	Segment_tree(const vector<int>& a) {
		n = a.size();
		tree.resize(4 * n);
		build(0, 0, n, a);
	}
	int get_max(int l, int r) {
		return _get_max(0, 0, n, l, r + 1);
	}
};

int main() {
	int n, q;
	cin >> n >> q;
	vector<int> a(n);
	bool ascend = true;
	for (int i = 0; i < n; i++) {
		cin >> a[i];
		a[i]--;
		if (i > 0 && a[i] < a[i - 1]) {
			ascend = false;
		}
	}
	if (n <= 3000) {
		vector<vector<int>> cnt(n, vector<int>(n, 0));
		for (int start = 0; start < n; start++) {
			cnt[start][0]++;
			int l = start, r = start;
			int move = 1;
			while (l > 0 && r < n - 1) {
				if (a[l - 1] < a[r + 1]) {
					cnt[a[l - 1]][move]++;
					l--;
				}
				else {
					cnt[a[r + 1]][move]++;
					r++;
				}
				move++;
			}
			while (l > 0) {
				cnt[a[l - 1]][move]++;
				l--;
				move++;
			}
			while (r < n - 1) {
				cnt[a[r + 1]][move]++;
				r++;
				move++;
			}
		}
		while (q--) {
			int p, k;
			cin >> p >> k;
			p--;
			k--;
			cout << cnt[a[p]][k] << '\n';
		}
	}
	else if (ascend) {
		while (q--) {
			int p, k;
			cin >> p >> k;
			p--;
			k--;
			int ans = 0;
			if (n - p - 1 >= k) {
				ans++;
			}
			if (k == p) {
				ans += p;
			}
			cout << ans << '\n';
		}
	}
	else {
		Segment_tree tree(a);
		bool same_p = true;
		int last_p = -1;
		vector<int> mem_p(n, -1);
		vector<pair<int, int>> qs(q);
		while (q--) {
			int p, k;
			cin >> p >> k;
			p--;
			k--;
			if (last_p != -1 && p != last_p) {
				same_p = false;
			}
			last_p = p;
			qs[qs.size() - q - 1] = make_pair(p, k);
		}
		if (!same_p) {
			for (auto para : qs) {
				int p = para.first;
				int k = para.second;
				if (k == 0) {
					cout << "1\n";
				}
				else {
					int cnt = 0;
					for (int i = 0; i < n; i++) {
						if (i == p || i > p + k || i < p - k) {
							continue;
						}
						if (i > p) {
							if (p + k >= n) {
								continue;
							}
							int maxl = tree.get_max(p, i - 1);
							int maxr = tree.get_max(i + 1, p + k);
							if (maxr < maxl && (p + k + 1 == n || a[p + k + 1] > maxl)) {
								cnt++;
							}
						}
						else {
							if (p - k < 0) {
								continue;
							}
							int maxl = tree.get_max(p - k, i - 1);
							int maxr = tree.get_max(i + 1, p);
							if (maxl < maxr && (p - k == 0 || a[p - k - 1] > maxr)) {
								cnt++;
							}
						}
					}
					cout << cnt << '\n';
				}
			}
		}
		else {
			int p = qs[0].first;
			vector<int> cnt(n, 0);
			cnt[0] = 1;
			for (int i = 0; i < n; i++) {
				if (i == p) {
					continue;
				}
				if (i > p) {
					int maxl = tree.get_max(p, i - 1);
					int L = i, R = n - 1;
					while (R - L > 1) {
						int M = (L + R) / 2;
						if (tree.get_max(i + 1, M) < maxl) {
							L = M;
						}
						else {
							R = M;
						}
					}
					cnt[L - p]++;
				}
				else {
					if (i < p) {
						int maxr = tree.get_max(i + 1, p);
						int L = 0, R = i;
						while (R - L > 1) {
							int M = (L + R) / 2;
							if (tree.get_max(M, i - 1) < maxr) {
								R = M;
							}
							else {
								L = M;
							}
						}
						cnt[p - L]++;
					}
				}
			}
			for (auto para : qs) {
				cout << cnt[para.second] << '\n';
			}
		}
	}
}
